@@ -8,7 +8,7 @@
 #include "py/dynruntime.h"
 
 // Helper function to compute factorial
-STATIC mp_int_t factorial_helper(mp_int_t x) {
+static mp_int_t factorial_helper(mp_int_t x) {
     if (x == 0) {
         return 1;
     }
@@ -16,7 +16,7 @@ STATIC mp_int_t factorial_helper(mp_int_t x) {
 }
 
 // This is the function which will be called from Python, as factorial(x)
-STATIC mp_obj_t factorial(mp_obj_t x_obj) {
+static mp_obj_t factorial(mp_obj_t x_obj) {
     // Extract the integer from the MicroPython input object
     mp_int_t x = mp_obj_get_int(x_obj);
     // Calculate the factorial
@@ -25,7 +25,7 @@ STATIC mp_obj_t factorial(mp_obj_t x_obj) {
     return mp_obj_new_int(result);
 }
 // Define a Python reference to the function above
-STATIC MP_DEFINE_CONST_FUN_OBJ_1(factorial_obj, factorial);
+static MP_DEFINE_CONST_FUN_OBJ_1(factorial_obj, factorial);
 
 // This is the entry point and is called when the module is imported
 mp_obj_t mpy_init(mp_obj_fun_bc_t *self, size_t n_args, size_t n_kw, mp_obj_t *args) {
