@@ -40,6 +40,19 @@
 #if MICROPY_PY_NETWORK_CYW43
 // So that CYW43_LINK_xxx constants are available to MICROPY_PORT_NETWORK_INTERFACES.
 #include "lib/cyw43-driver/src/cyw43.h"
+extern const struct _mp_obj_type_t mp_network_cyw43_type;
+#endif
+
+#if MICROPY_PY_NETWORK_WIZNET5K
+extern const struct _mp_obj_type_t mod_network_nic_type_wiznet5k;
+#endif
+
+#if MICROPY_PY_NETWORK_NINAW10
+extern const struct _mp_obj_type_t mod_network_nic_type_nina;
+#endif
+
+#if MICROPY_PY_NETWORK_ESP_HOSTED
+extern const struct _mp_obj_type_t mod_network_esp_hosted_type;
 #endif
 
 #ifdef MICROPY_PY_NETWORK_INCLUDEFILE
@@ -99,16 +112,16 @@ mp_obj_t mod_network_find_nic(const uint8_t *ip) {
     mp_raise_msg(&mp_type_OSError, MP_ERROR_TEXT("no available NIC"));
 }
 
-STATIC mp_obj_t network_route(void) {
+static mp_obj_t network_route(void) {
     return MP_OBJ_FROM_PTR(&MP_STATE_PORT(mod_network_nic_list));
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_0(network_route_obj, network_route);
+static MP_DEFINE_CONST_FUN_OBJ_0(network_route_obj, network_route);
 
 MP_REGISTER_ROOT_POINTER(mp_obj_list_t mod_network_nic_list);
 
 #endif // MICROPY_PORT_NETWORK_INTERFACES
 
-STATIC mp_obj_t network_country(size_t n_args, const mp_obj_t *args) {
+static mp_obj_t network_country(size_t n_args, const mp_obj_t *args) {
     if (n_args == 0) {
         return mp_obj_new_str(mod_network_country_code, 2);
     } else {
@@ -127,7 +140,7 @@ MP_DEFINE_CONST_FUN_OBJ_VAR_BETWEEN(mod_network_country_obj, 0, 1, network_count
 
 mp_obj_t mod_network_hostname(size_t n_args, const mp_obj_t *args) {
     if (n_args == 0) {
-        return mp_obj_new_str(mod_network_hostname_data, strlen(mod_network_hostname_data));
+        return mp_obj_new_str_from_cstr(mod_network_hostname_data);
     } else {
         size_t len;
         const char *str = mp_obj_str_get_data(args[0], &len);
@@ -139,12 +152,26 @@ mp_obj_t mod_network_hostname(size_t n_args, const mp_obj_t *args) {
         return mp_const_none;
     }
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_VAR_BETWEEN(mod_network_hostname_obj, 0, 1, mod_network_hostname);
+static MP_DEFINE_CONST_FUN_OBJ_VAR_BETWEEN(mod_network_hostname_obj, 0, 1, mod_network_hostname);
 
-STATIC const mp_rom_map_elem_t mp_module_network_globals_table[] = {
+#if LWIP_VERSION_MAJOR >= 2
+MP_DEFINE_CONST_FUN_OBJ_KW(mod_network_ipconfig_obj, 0, mod_network_ipconfig);
+#endif
+#if MICROPY_PY_NETWORK_NINAW10
+MP_DEFINE_CONST_FUN_OBJ_KW(mod_network_ipconfig_obj, 0, network_ninaw10_ipconfig);
+#endif
+
+static const mp_rom_map_elem_t mp_module_network_globals_table[] = {
     { MP_ROM_QSTR(MP_QSTR___name__), MP_ROM_QSTR(MP_QSTR_network) },
     { MP_ROM_QSTR(MP_QSTR_country), MP_ROM_PTR(&mod_network_country_obj) },
     { MP_ROM_QSTR(MP_QSTR_hostname), MP_ROM_PTR(&mod_network_hostname_obj) },
+    #if LWIP_VERSION_MAJOR >= 2 || MICROPY_PY_NETWORK_NINAW10
+    { MP_ROM_QSTR(MP_QSTR_ipconfig), MP_ROM_PTR(&mod_network_ipconfig_obj) },
+    #endif
+
+    #if MICROPY_PY_NETWORK_PPP_LWIP
+    { MP_ROM_QSTR(MP_QSTR_PPP), MP_ROM_PTR(&mp_network_ppp_lwip_type) },
+    #endif
 
     // Defined per port in mpconfigport.h
     #ifdef MICROPY_PORT_NETWORK_INTERFACES
@@ -152,6 +179,32 @@ STATIC const mp_rom_map_elem_t mp_module_network_globals_table[] = {
     MICROPY_PORT_NETWORK_INTERFACES
     #endif
 
+    #if MICROPY_PY_NETWORK_CYW43
+    { MP_ROM_QSTR(MP_QSTR_WLAN), MP_ROM_PTR(&mp_network_cyw43_type) },
+    // CYW43 status constants, currently for rp2 port only.
+    // TODO move these to WIFI module for all ports.
+    #if defined(PICO_PROGRAM_NAME) && defined(CYW43_LINK_DOWN)
+    { MP_ROM_QSTR(MP_QSTR_STAT_IDLE), MP_ROM_INT(CYW43_LINK_DOWN) },
+    { MP_ROM_QSTR(MP_QSTR_STAT_CONNECTING), MP_ROM_INT(CYW43_LINK_JOIN) },
+    { MP_ROM_QSTR(MP_QSTR_STAT_WRONG_PASSWORD), MP_ROM_INT(CYW43_LINK_BADAUTH) },
+    { MP_ROM_QSTR(MP_QSTR_STAT_NO_AP_FOUND), MP_ROM_INT(CYW43_LINK_NONET) },
+    { MP_ROM_QSTR(MP_QSTR_STAT_CONNECT_FAIL), MP_ROM_INT(CYW43_LINK_FAIL) },
+    { MP_ROM_QSTR(MP_QSTR_STAT_GOT_IP), MP_ROM_INT(CYW43_LINK_UP) },
+    #endif
+    #endif
+
+    #if MICROPY_PY_NETWORK_WIZNET5K
+    { MP_ROM_QSTR(MP_QSTR_WIZNET5K), MP_ROM_PTR(&mod_network_nic_type_wiznet5k) },
+    #endif
+
+    #if MICROPY_PY_NETWORK_NINAW10
+    { MP_ROM_QSTR(MP_QSTR_WLAN), MP_ROM_PTR(&mod_network_nic_type_nina) },
+    #endif
+
+    #if MICROPY_PY_NETWORK_ESP_HOSTED
+    { MP_ROM_QSTR(MP_QSTR_WLAN), MP_ROM_PTR(&mod_network_esp_hosted_type) },
+    #endif
+
     // Allow a port to take mostly full control of the network module.
     #ifdef MICROPY_PY_NETWORK_MODULE_GLOBALS_INCLUDEFILE
     #include MICROPY_PY_NETWORK_MODULE_GLOBALS_INCLUDEFILE
@@ -162,7 +215,7 @@ STATIC const mp_rom_map_elem_t mp_module_network_globals_table[] = {
     #endif
 };
 
-STATIC MP_DEFINE_CONST_DICT(mp_module_network_globals, mp_module_network_globals_table);
+static MP_DEFINE_CONST_DICT(mp_module_network_globals, mp_module_network_globals_table);
 
 const mp_obj_module_t mp_module_network = {
     .base = { &mp_type_module },
