@@ -50,7 +50,7 @@ const mp_arg_t mp_irq_init_args[] = {
 /******************************************************************************
  DECLARE PRIVATE DATA
  ******************************************************************************/
-STATIC uint8_t mp_irq_priorities[] = { INT_PRIORITY_LVL_7, INT_PRIORITY_LVL_6, INT_PRIORITY_LVL_5, INT_PRIORITY_LVL_4,
+static uint8_t mp_irq_priorities[] = { INT_PRIORITY_LVL_7, INT_PRIORITY_LVL_6, INT_PRIORITY_LVL_5, INT_PRIORITY_LVL_4,
                                        INT_PRIORITY_LVL_3, INT_PRIORITY_LVL_2, INT_PRIORITY_LVL_1 };
 
 /******************************************************************************
@@ -143,7 +143,7 @@ void mp_irq_handler (mp_obj_t self_in) {
 /******************************************************************************/
 // MicroPython bindings
 
-STATIC mp_obj_t mp_irq_init(size_t n_args, const mp_obj_t *pos_args, mp_map_t *kw_args) {
+static mp_obj_t mp_irq_init(size_t n_args, const mp_obj_t *pos_args, mp_map_t *kw_args) {
     mp_irq_obj_t *self = pos_args[0];
     // this is a bit of a hack, but it let us reuse the callback_create method from our parent
     ((mp_obj_t *)pos_args)[0] = self->parent;
@@ -152,35 +152,35 @@ STATIC mp_obj_t mp_irq_init(size_t n_args, const mp_obj_t *pos_args, mp_map_t *k
 }
 MP_DEFINE_CONST_FUN_OBJ_KW(mp_irq_init_obj, 1, mp_irq_init);
 
-STATIC mp_obj_t mp_irq_enable (mp_obj_t self_in) {
+static mp_obj_t mp_irq_enable (mp_obj_t self_in) {
     mp_irq_obj_t *self = self_in;
     self->methods->enable(self->parent);
     self->isenabled = true;
     return mp_const_none;
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_1(mp_irq_enable_obj, mp_irq_enable);
+static MP_DEFINE_CONST_FUN_OBJ_1(mp_irq_enable_obj, mp_irq_enable);
 
-STATIC mp_obj_t mp_irq_disable (mp_obj_t self_in) {
+static mp_obj_t mp_irq_disable (mp_obj_t self_in) {
     mp_irq_obj_t *self = self_in;
     self->methods->disable(self->parent);
     self->isenabled = false;
     return mp_const_none;
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_1(mp_irq_disable_obj, mp_irq_disable);
+static MP_DEFINE_CONST_FUN_OBJ_1(mp_irq_disable_obj, mp_irq_disable);
 
-STATIC mp_obj_t mp_irq_flags (mp_obj_t self_in) {
+static mp_obj_t mp_irq_flags (mp_obj_t self_in) {
     mp_irq_obj_t *self = self_in;
     return mp_obj_new_int(self->methods->flags(self->parent));
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_1(mp_irq_flags_obj, mp_irq_flags);
+static MP_DEFINE_CONST_FUN_OBJ_1(mp_irq_flags_obj, mp_irq_flags);
 
-STATIC mp_obj_t mp_irq_call(mp_obj_t self_in, size_t n_args, size_t n_kw, const mp_obj_t *args) {
+static mp_obj_t mp_irq_call(mp_obj_t self_in, size_t n_args, size_t n_kw, const mp_obj_t *args) {
     mp_arg_check_num(n_args, n_kw, 0, 0, false);
     mp_irq_handler (self_in);
     return mp_const_none;
 }
 
-STATIC const mp_rom_map_elem_t mp_irq_locals_dict_table[] = {
+static const mp_rom_map_elem_t mp_irq_locals_dict_table[] = {
     // instance methods
     { MP_ROM_QSTR(MP_QSTR_init),                MP_ROM_PTR(&mp_irq_init_obj) },
     { MP_ROM_QSTR(MP_QSTR_enable),              MP_ROM_PTR(&mp_irq_enable_obj) },
@@ -188,12 +188,14 @@ STATIC const mp_rom_map_elem_t mp_irq_locals_dict_table[] = {
     { MP_ROM_QSTR(MP_QSTR_flags),               MP_ROM_PTR(&mp_irq_flags_obj) },
 };
 
-STATIC MP_DEFINE_CONST_DICT(mp_irq_locals_dict, mp_irq_locals_dict_table);
+static MP_DEFINE_CONST_DICT(mp_irq_locals_dict, mp_irq_locals_dict_table);
 
-const mp_obj_type_t mp_irq_type = {
-    { &mp_type_type },
-    .name = MP_QSTR_irq,
-    .call = mp_irq_call,
-    .locals_dict = (mp_obj_t)&mp_irq_locals_dict,
-};
+MP_DEFINE_CONST_OBJ_TYPE(
+    mp_irq_type,
+    MP_QSTR_irq,
+    MP_TYPE_FLAG_NONE,
+    call, mp_irq_call,
+    locals_dict, &mp_irq_locals_dict
+    );
 
+MP_REGISTER_ROOT_POINTER(mp_obj_list_t mp_irq_obj_list);
