@@ -1,8 +1,8 @@
 #define MICROPY_HW_BOARD_NAME               "LOLIN_S2_MINI"
 #define MICROPY_HW_MCU_NAME                 "ESP32-S2FN4R2"
+#define MICROPY_PY_NETWORK_HOSTNAME_DEFAULT "mpy-s2-mini"
 
 #define MICROPY_PY_BLUETOOTH                (0)
-#define MICROPY_HW_ENABLE_SDCARD            (0)
 
 #define MICROPY_HW_I2C0_SCL                 (35)
 #define MICROPY_HW_I2C0_SDA                 (33)
