@@ -1,7 +1,6 @@
 #define MICROPY_HW_BOARD_NAME               "TinyS3"
 #define MICROPY_HW_MCU_NAME                 "ESP32-S3-FN8"
-
-#define MICROPY_PY_MACHINE_DAC              (0)
+#define MICROPY_PY_NETWORK_HOSTNAME_DEFAULT "TinyS3"
 
 #define MICROPY_HW_I2C0_SCL                 (9)
 #define MICROPY_HW_I2C0_SDA                 (8)
