@@ -1,13 +1,13 @@
 import gc
-import uos
+import vfs
 from flashbdev import bdev
 
 try:
     if bdev:
-        uos.mount(bdev, "/")
+        vfs.mount(bdev, "/")
 except OSError:
     import inisetup
 
-    vfs = inisetup.setup()
+    inisetup.setup()
 
 gc.collect()
