@@ -36,8 +36,9 @@
 #include <stdio.h>
 #include "driver/uart.h" // For uart_get_sclk_freq()
 #include "hal/uart_hal.h"
+#include "soc/uart_periph.h"
 
-STATIC void uart_irq_handler(void *arg);
+static void uart_irq_handler(void *arg);
 
 // Declaring the HAL structure on the stack saves a tiny amount of static RAM
 #define REPL_HAL_DEFN() { .dev = UART_LL_GET_HW(MICROPY_HW_UART_REPL) }
@@ -50,11 +51,7 @@ STATIC void uart_irq_handler(void *arg);
 
 void uart_stdout_init(void) {
     uart_hal_context_t repl_hal = REPL_HAL_DEFN();
-    #if ESP_IDF_VERSION < ESP_IDF_VERSION_VAL(5, 3, 0)
-    uart_sclk_t sclk;
-    #else
     soc_module_clk_t sclk;
-    #endif
     uint32_t sclk_freq;
 
     uart_hal_get_sclk(&repl_hal, &sclk); // To restore SCLK after uart_hal_init() resets it
@@ -99,7 +96,7 @@ int uart_stdout_tx_strn(const char *str, size_t len) {
 }
 
 // all code executed in ISR must be in IRAM, and any const data must be in DRAM
-STATIC void IRAM_ATTR uart_irq_handler(void *arg) {
+static void IRAM_ATTR uart_irq_handler(void *arg) {
     uint8_t rbuf[SOC_UART_FIFO_LEN];
     int len;
     uart_hal_context_t repl_hal = REPL_HAL_DEFN();
