@@ -30,7 +30,7 @@
 #include "user_interface.h"
 #include "extmod/misc.h"
 
-NORETURN void call_user_start(void);
+MP_NORETURN void call_user_start(void);
 void ets_printf(const char *fmt, ...);
 extern char flashchip;
 
