@@ -36,12 +36,12 @@ const char esp_help_text[] =
     "Basic WiFi configuration:\n"
     "\n"
     "import network\n"
-    "sta_if = network.WLAN(network.STA_IF); sta_if.active(True)\n"
+    "sta_if = network.WLAN(network.WLAN.IF_STA); sta_if.active(True)\n"
     "sta_if.scan()                             # Scan for available access points\n"
     "sta_if.connect(\"<AP_name>\", \"<key>\") # Connect to an AP\n"
     "sta_if.isconnected()                      # Check for successful connection\n"
     "# Change name/password of ESP8266's AP:\n"
-    "ap_if = network.WLAN(network.AP_IF)\n"
+    "ap_if = network.WLAN(network.WLAN.IF_AP)\n"
     "ap_if.config(ssid=\"<AP_NAME>\", security=network.AUTH_WPA_WPA2_PSK, key=\"<key>\")\n"
     "\n"
     "Control commands:\n"
