@@ -20,7 +20,7 @@ Direct wiring on SD card (SPI):
   ---------------------------------
 """
 
-import os
+import os, vfs
 from machine import SPI, Pin
 from sdcard import SDCard
 
@@ -28,7 +28,7 @@ from sdcard import SDCard
 def mnt():
     cs = Pin("P22", mode=Pin.OUT)
     sd = SDCard(SPI(0), cs)
-    os.mount(sd, "/")
+    vfs.mount(sd, "/")
 
 
 def list():
