@@ -38,7 +38,7 @@
 #define PYB_LED_MODULE
 #endif
 
-STATIC const mp_rom_map_elem_t board_module_globals_table[] = {
+static const mp_rom_map_elem_t board_module_globals_table[] = {
     { MP_ROM_QSTR(MP_QSTR___name__), MP_ROM_QSTR(MP_QSTR_board) },
     #if MICROPY_REPL_INFO
     { MP_ROM_QSTR(MP_QSTR_repl_info), MP_ROM_PTR(&pyb_set_repl_info_obj) },
@@ -47,7 +47,7 @@ STATIC const mp_rom_map_elem_t board_module_globals_table[] = {
 };
 
 
-STATIC MP_DEFINE_CONST_DICT(board_module_globals, board_module_globals_table);
+static MP_DEFINE_CONST_DICT(board_module_globals, board_module_globals_table);
 
 const mp_obj_module_t board_module = {
     .base = { &mp_type_module },
