@@ -1,4 +1,4 @@
-#define MICROPY_HW_BOARD_NAME       "Sparkfun SAMD51 Thing Plus"
+#define MICROPY_HW_BOARD_NAME       "SparkFun SAMD51 Thing Plus"
 #define MICROPY_HW_MCU_NAME         "SAMD51J20A"
 
 #define MICROPY_HW_XOSC32K          (1)
