@@ -78,6 +78,9 @@ unsigned long trng_random_u32(int delay);
 #ifndef MICROPY_PY_ONEWIRE
 #define MICROPY_PY_ONEWIRE              (SAMD21_EXTRA_FEATURES)
 #endif
+#ifndef MICROPY_PY_MACHINE_I2C_TARGET
+#define MICROPY_PY_MACHINE_I2C_TARGET   (SAMD21_EXTRA_FEATURES)
+#endif
 
 #ifndef MICROPY_PY_MACHINE_PIN_BOARD_CPU
 #define MICROPY_PY_MACHINE_PIN_BOARD_CPU (1)
