@@ -45,7 +45,7 @@ extern const mp_obj_type_t samd_spiflash_type;
 #define SPIFLASH_TYPE samd_spiflash_type
 #endif
 
-STATIC mp_obj_t samd_pininfo(mp_obj_t pin_obj) {
+static mp_obj_t samd_pininfo(mp_obj_t pin_obj) {
     const machine_pin_obj_t *pin_af = pin_find(pin_obj);
     #if defined(MCU_SAMD21)
     mp_obj_t tuple[7] = {
@@ -74,14 +74,14 @@ STATIC mp_obj_t samd_pininfo(mp_obj_t pin_obj) {
     #endif
     return mp_const_none;
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_1(samd_pininfo_obj, samd_pininfo);
+static MP_DEFINE_CONST_FUN_OBJ_1(samd_pininfo_obj, samd_pininfo);
 
-STATIC const mp_rom_map_elem_t samd_module_globals_table[] = {
+static const mp_rom_map_elem_t samd_module_globals_table[] = {
     { MP_ROM_QSTR(MP_QSTR___name__), MP_ROM_QSTR(MP_QSTR_samd) },
     { MP_ROM_QSTR(MP_QSTR_Flash),    MP_ROM_PTR(&SPIFLASH_TYPE) },
     { MP_ROM_QSTR(MP_QSTR_pininfo),  MP_ROM_PTR(&samd_pininfo_obj) },
 };
-STATIC MP_DEFINE_CONST_DICT(samd_module_globals, samd_module_globals_table);
+static MP_DEFINE_CONST_DICT(samd_module_globals, samd_module_globals_table);
 
 const mp_obj_module_t mp_module_samd = {
     .base = { &mp_type_module },
