@@ -47,6 +47,7 @@ extern int mp_interrupt_char;
 extern ringbuf_t stdin_ringbuf;
 extern volatile uint32_t systick_ms;
 uint64_t mp_hal_ticks_us_64(void);
+void mp_hal_time_ns_set_from_rtc(void);
 
 void mp_hal_set_interrupt_char(int c);
 
@@ -94,10 +95,6 @@ static inline mp_uint_t mp_hal_ticks_cpu(void) {
 }
 #endif
 
-static inline uint64_t mp_hal_time_ns(void) {
-    return mp_hal_ticks_us_64() * 1000;
-}
-
 // C-level pin HAL
 
 #include "py/obj.h"
