@@ -29,6 +29,7 @@
 #include "py/mphal.h"
 #include "py/runtime.h"
 #include "i2c.h"
+#include "i2cslave.h"
 
 #if MICROPY_HW_ENABLE_HW_I2C
 
@@ -551,6 +552,10 @@ static const uint8_t i2c_available =
     #endif
 ;
 
+#if MICROPY_HW_ENABLE_HW_I2C_TARGET
+uint8_t i2c_target_enabled;
+#endif
+
 int i2c_find_peripheral(mp_obj_t id) {
     int i2c_id = 0;
     if (mp_obj_is_str(id)) {
@@ -590,4 +595,144 @@ int i2c_find_peripheral(mp_obj_t id) {
     return i2c_id;
 }
 
+#if MICROPY_HW_ENABLE_HW_I2C_TARGET || MICROPY_PY_PYB_LEGACY
+
+#if defined(MICROPY_HW_I2C1_SCL)
+void I2C1_EV_IRQHandler(void) {
+    MP_STATIC_ASSERT(I2C1_EV_IRQn > 0);
+    IRQ_ENTER(I2C1_EV_IRQn);
+    #if MICROPY_HW_ENABLE_HW_I2C_TARGET
+    if (i2c_target_enabled & 1) {
+        i2c_slave_irq_handler(I2C1);
+    } else
+    #endif
+    {
+        #if MICROPY_PY_PYB_LEGACY
+        i2c_ev_irq_handler(1);
+        #endif
+    }
+    IRQ_EXIT(I2C1_EV_IRQn);
+}
+
+void I2C1_ER_IRQHandler(void) {
+    MP_STATIC_ASSERT(I2C1_ER_IRQn > 0);
+    IRQ_ENTER(I2C1_ER_IRQn);
+    #if MICROPY_HW_ENABLE_HW_I2C_TARGET
+    if (i2c_target_enabled & 1) {
+        i2c_slave_irq_handler(I2C1);
+    } else
+    #endif
+    {
+        #if MICROPY_PY_PYB_LEGACY
+        i2c_er_irq_handler(1);
+        #endif
+    }
+    IRQ_EXIT(I2C1_ER_IRQn);
+}
+#endif // defined(MICROPY_HW_I2C1_SCL)
+
+#if defined(MICROPY_HW_I2C2_SCL)
+void I2C2_EV_IRQHandler(void) {
+    MP_STATIC_ASSERT(I2C2_EV_IRQn > 0);
+    IRQ_ENTER(I2C2_EV_IRQn);
+    #if MICROPY_HW_ENABLE_HW_I2C_TARGET
+    if (i2c_target_enabled & 2) {
+        i2c_slave_irq_handler(I2C2);
+    } else
+    #endif
+    {
+        #if MICROPY_PY_PYB_LEGACY
+        i2c_ev_irq_handler(2);
+        #endif
+    }
+    IRQ_EXIT(I2C2_EV_IRQn);
+}
+
+void I2C2_ER_IRQHandler(void) {
+    MP_STATIC_ASSERT(I2C2_ER_IRQn > 0);
+    IRQ_ENTER(I2C2_ER_IRQn);
+    #if MICROPY_HW_ENABLE_HW_I2C_TARGET
+    if (i2c_target_enabled & 2) {
+        i2c_slave_irq_handler(I2C2);
+    } else
+    #endif
+    {
+        #if MICROPY_PY_PYB_LEGACY
+        i2c_er_irq_handler(2);
+        #endif
+    }
+    IRQ_EXIT(I2C2_ER_IRQn);
+}
+#endif // defined(MICROPY_HW_I2C2_SCL)
+
+#if defined(MICROPY_HW_I2C3_SCL)
+void I2C3_EV_IRQHandler(void) {
+    MP_STATIC_ASSERT(I2C3_EV_IRQn > 0);
+    IRQ_ENTER(I2C3_EV_IRQn);
+    #if MICROPY_HW_ENABLE_HW_I2C_TARGET
+    if (i2c_target_enabled & 4) {
+        i2c_slave_irq_handler(I2C3);
+    } else
+    #endif
+    {
+        #if MICROPY_PY_PYB_LEGACY
+        i2c_ev_irq_handler(3);
+        #endif
+    }
+    IRQ_EXIT(I2C3_EV_IRQn);
+}
+
+void I2C3_ER_IRQHandler(void) {
+    MP_STATIC_ASSERT(I2C3_ER_IRQn > 0);
+    IRQ_ENTER(I2C3_ER_IRQn);
+    #if MICROPY_HW_ENABLE_HW_I2C_TARGET
+    if (i2c_target_enabled & 4) {
+        i2c_slave_irq_handler(I2C3);
+    } else
+    #endif
+    {
+        #if MICROPY_PY_PYB_LEGACY
+        i2c_er_irq_handler(3);
+        #endif
+    }
+    IRQ_EXIT(I2C3_ER_IRQn);
+}
+#endif // defined(MICROPY_HW_I2C3_SCL)
+
+#if defined(MICROPY_HW_I2C4_SCL)
+void I2C4_EV_IRQHandler(void) {
+    MP_STATIC_ASSERT(I2C4_EV_IRQn > 0);
+    IRQ_ENTER(I2C4_EV_IRQn);
+    #if MICROPY_HW_ENABLE_HW_I2C_TARGET
+    if (i2c_target_enabled & 8) {
+        i2c_slave_irq_handler(I2C4);
+    } else
+    #endif
+    {
+        #if MICROPY_PY_PYB_LEGACY
+        i2c_ev_irq_handler(4);
+        #endif
+    }
+    IRQ_EXIT(I2C4_EV_IRQn);
+}
+
+void I2C4_ER_IRQHandler(void) {
+    MP_STATIC_ASSERT(I2C4_ER_IRQn > 0);
+    IRQ_ENTER(I2C4_ER_IRQn);
+    #if MICROPY_HW_ENABLE_HW_I2C_TARGET
+    if (i2c_target_enabled & 8) {
+        i2c_slave_irq_handler(I2C4);
+    } else
+    #endif
+    {
+        #if MICROPY_PY_PYB_LEGACY
+        i2c_er_irq_handler(4);
+        #endif
+    }
+    IRQ_EXIT(I2C4_ER_IRQn);
+}
+#endif // defined(MICROPY_HW_I2C4_SCL)
+
+#endif // MICROPY_PY_PYB_LEGACY
+
 #endif // MICROPY_HW_ENABLE_HW_I2C
