@@ -30,7 +30,7 @@
 #include "py/mphal.h"
 #include "adc.h"
 
-#if defined(STM32F0) || defined(STM32G0) || defined(STM32G4) || defined(STM32H5) || defined(STM32H7) || defined(STM32L0) || defined(STM32L4) || defined(STM32WB) || defined(STM32WL)
+#if defined(STM32F0) || defined(STM32G0) || defined(STM32G4) || defined(STM32H5) || defined(STM32H7) || defined(STM32L0) || defined(STM32L4) || defined(STM32N6) || defined(STM32WB) || defined(STM32WL)
 #define ADC_V2 (1)
 #else
 #define ADC_V2 (0)
@@ -80,11 +80,14 @@
 #define ADC_SAMPLETIME_DEFAULT      ADC_SAMPLETIME_12CYCLES_5
 #define ADC_SAMPLETIME_DEFAULT_INT  ADC_SAMPLETIME_160CYCLES_5
 #elif defined(STM32L1)
-#define ADC_SAMPLETIME_DEFAULT      ADC_SAMPLETIME_384CYCLES
+#define ADC_SAMPLETIME_DEFAULT      ADC_SAMPLETIME_16CYCLES
 #define ADC_SAMPLETIME_DEFAULT_INT  ADC_SAMPLETIME_384CYCLES
 #elif defined(STM32L4) || defined(STM32WB)
 #define ADC_SAMPLETIME_DEFAULT      ADC_SAMPLETIME_12CYCLES_5
 #define ADC_SAMPLETIME_DEFAULT_INT  ADC_SAMPLETIME_247CYCLES_5
+#elif defined(STM32N6)
+#define ADC_SAMPLETIME_DEFAULT      ADC_SAMPLETIME_11CYCLES_5
+#define ADC_SAMPLETIME_DEFAULT_INT  ADC_SAMPLETIME_246CYCLES_5
 #endif
 
 // Timeout for waiting for end-of-conversion
@@ -112,7 +115,7 @@ typedef enum _machine_adc_internal_ch_t {
 
 // Convert machine_adc_internal_ch_t value to STM32 library ADC channel literal.
 // This function is required as literals are uint32_t types that don't map with MP_ROM_INT (31 bit signed).
-STATIC uint32_t adc_ll_channel(uint32_t channel_id) {
+static uint32_t adc_ll_channel(uint32_t channel_id) {
     uint32_t adc_ll_ch;
     switch (channel_id) {
         // external channels map 1:1
@@ -127,6 +130,8 @@ STATIC uint32_t adc_ll_channel(uint32_t channel_id) {
         case MACHINE_ADC_INT_CH_TEMPSENSOR:
             #if defined(STM32G4)
             adc_ll_ch = ADC_CHANNEL_TEMPSENSOR_ADC1;
+            #elif defined(STM32N6)
+            adc_ll_ch = ADC_CHANNEL_0; // TODO
             #else
             adc_ll_ch = ADC_CHANNEL_TEMPSENSOR;
             #endif
@@ -154,7 +159,7 @@ static inline void adc_stabilisation_delay_us(uint32_t us) {
     mp_hal_delay_us(us + 1);
 }
 
-STATIC void adc_wait_eoc(ADC_TypeDef *adc, int32_t timeout_ms) {
+static void adc_wait_eoc(ADC_TypeDef *adc, int32_t timeout_ms) {
     uint32_t t0 = mp_hal_ticks_ms();
     #if ADC_V2
     while (!(adc->ISR & ADC_ISR_EOC))
@@ -169,9 +174,9 @@ STATIC void adc_wait_eoc(ADC_TypeDef *adc, int32_t timeout_ms) {
 }
 
 #if defined(STM32H7)
-STATIC const uint8_t adc_cr_to_bits_table[] = {16, 14, 12, 10, 8, 8, 8, 8};
+static const uint8_t adc_cr_to_bits_table[] = {16, 14, 12, 10, 8, 8, 8, 8};
 #else
-STATIC const uint8_t adc_cr_to_bits_table[] = {12, 10, 8, 6};
+static const uint8_t adc_cr_to_bits_table[] = {12, 10, 8, 6};
 #endif
 
 void adc_config(ADC_TypeDef *adc, uint32_t bits) {
@@ -183,7 +188,7 @@ void adc_config(ADC_TypeDef *adc, uint32_t bits) {
     if (adc == ADC1) {
         #if defined(STM32H5)
         __HAL_RCC_ADC_CLK_ENABLE();
-        #elif defined(STM32G4) || defined(STM32H7)
+        #elif defined(STM32G4) || defined(STM32H7) || defined(STM32N6)
         __HAL_RCC_ADC12_CLK_ENABLE();
         #else
         __HAL_RCC_ADC1_CLK_ENABLE();
@@ -193,7 +198,7 @@ void adc_config(ADC_TypeDef *adc, uint32_t bits) {
     if (adc == ADC2) {
         #if defined(STM32H5)
         __HAL_RCC_ADC_CLK_ENABLE();
-        #elif defined(STM32G4) || defined(STM32H7)
+        #elif defined(STM32G4) || defined(STM32H7) || defined(STM32N6)
         __HAL_RCC_ADC12_CLK_ENABLE();
         #else
         __HAL_RCC_ADC2_CLK_ENABLE();
@@ -225,13 +230,15 @@ void adc_config(ADC_TypeDef *adc, uint32_t bits) {
     ADC3_COMMON->CCR = 3 << ADC_CCR_CKMODE_Pos;
     #elif defined(STM32L0)
     ADC1_COMMON->CCR = 0; // ADCPR=PCLK/2
+    #elif defined(STM32L1)
+    ADC1_COMMON->CCR = 1 << ADC_CCR_ADCPRE_Pos; // ADCPRE=2
     #elif defined(STM32WB)
     ADC1_COMMON->CCR = 0 << ADC_CCR_PRESC_Pos | 0 << ADC_CCR_CKMODE_Pos; // PRESC=1, MODE=ASYNC
     #elif defined(STM32WL)
     ADC_COMMON->CCR = 0 << ADC_CCR_PRESC_Pos; // PRESC=1
     #endif
 
-    #if defined(STM32G4) || defined(STM32H5) || defined(STM32H7) || defined(STM32L4) || defined(STM32WB)
+    #if defined(STM32G4) || defined(STM32H5) || defined(STM32H7) || defined(STM32L4) || defined(STM32N6) || defined(STM32WB)
     if (adc->CR & ADC_CR_DEEPPWD) {
         adc->CR = 0; // disable deep powerdown
     }
@@ -255,6 +262,11 @@ void adc_config(ADC_TypeDef *adc, uint32_t bits) {
         LL_ADC_StartCalibration(adc);
         #elif defined(STM32G4) || defined(STM32H5) || defined(STM32L4) || defined(STM32WB)
         LL_ADC_StartCalibration(adc, LL_ADC_SINGLE_ENDED);
+        #elif defined(STM32N6)
+        ADC_HandleTypeDef hadc;
+        hadc.Instance = adc;
+        hadc.State = 0;
+        HAL_ADCEx_Calibration_Start(&hadc, ADC_SINGLE_ENDED);
         #else
         LL_ADC_StartCalibration(adc, LL_ADC_CALIB_OFFSET_LINEARITY, LL_ADC_SINGLE_ENDED);
         #endif
@@ -310,11 +322,17 @@ void adc_config(ADC_TypeDef *adc, uint32_t bits) {
     uint32_t cfgr = res << ADC_CFGR_RES_Pos;
     adc->CFGR = (adc->CFGR & ~cfgr_clr) | cfgr;
 
+    #elif defined(STM32N6)
+
+    uint32_t cfgr1_clr = ADC_CFGR1_CONT | ADC_CFGR1_EXTEN;
+    uint32_t cfgr1 = res << ADC_CFGR1_RES_Pos;
+    adc->CFGR1 = (adc->CFGR1 & ~cfgr1_clr) | cfgr1;
+
     #endif
 }
 
-STATIC int adc_get_bits(ADC_TypeDef *adc) {
-    #if defined(STM32F0) || defined(STM32G0) || defined(STM32L0) || defined(STM32WL)
+static int adc_get_bits(ADC_TypeDef *adc) {
+    #if defined(STM32F0) || defined(STM32G0) || defined(STM32L0) || defined(STM32N6) || defined(STM32WL)
     uint32_t res = (adc->CFGR1 & ADC_CFGR1_RES) >> ADC_CFGR1_RES_Pos;
     #elif defined(STM32F4) || defined(STM32F7) || defined(STM32L1)
     uint32_t res = (adc->CR1 & ADC_CR1_RES) >> ADC_CR1_RES_Pos;
@@ -324,7 +342,7 @@ STATIC int adc_get_bits(ADC_TypeDef *adc) {
     return adc_cr_to_bits_table[res];
 }
 
-STATIC void adc_config_channel(ADC_TypeDef *adc, uint32_t channel, uint32_t sample_time) {
+static void adc_config_channel(ADC_TypeDef *adc, uint32_t channel, uint32_t sample_time) {
     #if ADC_V2
     if (!(adc->CR & ADC_CR_ADEN)) {
         if (adc->CR & 0x3f) {
@@ -385,8 +403,34 @@ STATIC void adc_config_channel(ADC_TypeDef *adc, uint32_t channel, uint32_t samp
     }
     *smpr = (*smpr & ~(7 << (channel * 3))) | sample_time << (channel * 3); // select sample time
 
-    #elif defined(STM32G4) || defined(STM32H5) || defined(STM32H7) || defined(STM32L4) || defined(STM32WB)
-    #if defined(STM32G4) || defined(STM32H5) || defined(STM32H7A3xx) || defined(STM32H7A3xxQ) || defined(STM32H7B3xx) || defined(STM32H7B3xxQ)
+    #elif defined(STM32L1)
+
+    ADC_Common_TypeDef *adc_common = ADC1_COMMON;
+    if (channel == ADC_CHANNEL_VREFINT || channel == ADC_CHANNEL_TEMPSENSOR) {
+        adc_common->CCR |= ADC_CCR_TSVREFE;
+        if (channel == ADC_CHANNEL_TEMPSENSOR) {
+            adc_stabilisation_delay_us(ADC_TEMPSENSOR_DELAY_US);
+        }
+    }
+
+    adc->SQR1 = (1 - 1) << ADC_SQR1_L_Pos;
+    adc->SQR5 = (channel & 0x1f) << ADC_SQR5_SQ1_Pos;
+
+    __IO uint32_t *smpr;
+    if (channel >= 20) {
+        smpr = &adc->SMPR1;
+        channel -= 20;
+    } else if (channel >= 10) {
+        smpr = &adc->SMPR2;
+        channel -= 10;
+    } else {
+        smpr = &adc->SMPR3;
+    }
+    *smpr = (*smpr & ~(7 << (channel * 3))) | sample_time << (channel * 3); // select sample time
+
+    #elif defined(STM32G4) || defined(STM32H5) || defined(STM32H7) || defined(STM32L4) || defined(STM32N6) || defined(STM32WB)
+
+    #if defined(STM32G4) || defined(STM32H5) || defined(STM32H7A3xx) || defined(STM32H7A3xxQ) || defined(STM32H7B3xx) || defined(STM32H7B3xxQ) || defined(STM32N6)
     ADC_Common_TypeDef *adc_common = ADC12_COMMON;
     #elif defined(STM32H7)
     #if defined(ADC_VER_V5_V90)
@@ -404,6 +448,7 @@ STATIC void adc_config_channel(ADC_TypeDef *adc, uint32_t channel, uint32_t samp
     #endif
     if (channel == ADC_CHANNEL_VREFINT) {
         adc_common->CCR |= ADC_CCR_VREFEN;
+        #if !defined(STM32N6)
     #if defined(STM32G4)
     } else if (channel == ADC_CHANNEL_TEMPSENSOR_ADC1) {
         adc_common->CCR |= ADC_CCR_VSENSESEL;
@@ -412,19 +457,20 @@ STATIC void adc_config_channel(ADC_TypeDef *adc, uint32_t channel, uint32_t samp
         adc_common->CCR |= ADC_CCR_TSEN;
     #endif
         adc_stabilisation_delay_us(ADC_TEMPSENSOR_DELAY_US);
+        #endif
     } else if (channel == ADC_CHANNEL_VBAT) {
         #if defined(STM32G4)
         adc_common->CCR |= ADC_CCR_VBATSEL;
         #else
         adc_common->CCR |= ADC_CCR_VBATEN;
         #endif
-    #if defined(STM32H5)
+    #if defined(STM32H5) || defined(STM32N6)
     } else if (channel == ADC_CHANNEL_VDDCORE) {
         adc->OR |= ADC_OR_OP0; // Enable Vddcore channel on ADC2
     #endif
     }
-    #if defined(STM32G4) || defined(STM32H5)
-    // G4 and H5 use encoded literals for internal channels -> extract ADC channel for following code
+    #if defined(STM32G4) || defined(STM32H5) || defined(STM32N6) || defined(STM32WB)
+    // MCU uses encoded literals for internal channels -> extract ADC channel for following code
     if (__LL_ADC_IS_CHANNEL_INTERNAL(channel)) {
         channel = __LL_ADC_CHANNEL_TO_DECIMAL_NB(channel);
     }
@@ -443,12 +489,15 @@ STATIC void adc_config_channel(ADC_TypeDef *adc, uint32_t channel, uint32_t samp
     #endif
 }
 
-STATIC uint32_t adc_read_channel(ADC_TypeDef *adc) {
+static uint32_t adc_read_channel(ADC_TypeDef *adc) {
     uint32_t value;
-    #if defined(STM32G4)
-    // For STM32G4 there is errata 2.7.7, "Wrong ADC result if conversion done late after
-    // calibration or previous conversion".  According to the errata, this can be avoided
-    // by performing two consecutive ADC conversions and keeping the second result.
+    #if defined(STM32G4) || defined(STM32WB)
+    // For STM32G4 errata 2.7.7 / STM32WB errata 2.7.1:
+    // "Wrong ADC result if conversion done late after calibration or previous conversion"
+    // states an incorrect reading is returned if more than 1ms has elapsed since the last
+    // reading or calibration. According to the errata, this can be avoided by performing
+    // two consecutive ADC conversions and keeping the second result.
+    // Note: On STM32WB55 @ 64Mhz each ADC read takes ~ 3us.
     for (uint8_t i = 0; i < 2; i++)
     #endif
     {
@@ -520,7 +569,7 @@ typedef struct _machine_adc_obj_t {
     uint32_t sample_time;
 } machine_adc_obj_t;
 
-STATIC void mp_machine_adc_print(const mp_print_t *print, mp_obj_t self_in, mp_print_kind_t kind) {
+static void mp_machine_adc_print(const mp_print_t *print, mp_obj_t self_in, mp_print_kind_t kind) {
     machine_adc_obj_t *self = MP_OBJ_TO_PTR(self_in);
     unsigned adc_id = 1;
     #if defined(ADC2)
@@ -537,7 +586,7 @@ STATIC void mp_machine_adc_print(const mp_print_t *print, mp_obj_t self_in, mp_p
 }
 
 // ADC(id)
-STATIC mp_obj_t mp_machine_adc_make_new(const mp_obj_type_t *type, size_t n_args, size_t n_kw, const mp_obj_t *all_args) {
+static mp_obj_t mp_machine_adc_make_new(const mp_obj_type_t *type, size_t n_args, size_t n_kw, const mp_obj_t *all_args) {
     // Check number of arguments
     mp_arg_check_num(n_args, n_kw, 1, 1, false);
 
@@ -607,7 +656,7 @@ STATIC mp_obj_t mp_machine_adc_make_new(const mp_obj_type_t *type, size_t n_args
 }
 
 // read_u16()
-STATIC mp_int_t mp_machine_adc_read_u16(machine_adc_obj_t *self) {
+static mp_int_t mp_machine_adc_read_u16(machine_adc_obj_t *self) {
     return adc_config_and_read_u16(self->adc, self->channel, self->sample_time);
 }
 
