@@ -91,7 +91,7 @@
 #define USART_CR3_IE_ALL (USART_CR3_IE_BASE | USART_CR3_WUFIE)
 #endif
 
-#elif defined(STM32H7)
+#elif defined(STM32H7) || defined(STM32N6)
 #define USART_CR1_IE_ALL (USART_CR1_IE_BASE | USART_CR1_RXFFIE | USART_CR1_TXFEIE | USART_CR1_EOBIE | USART_CR1_RTOIE | USART_CR1_CMIE)
 #define USART_CR2_IE_ALL (USART_CR2_IE_BASE)
 #define USART_CR3_IE_ALL (USART_CR3_IE_BASE | USART_CR3_RXFTIE | USART_CR3_TCBGTIE | USART_CR3_TXFTIE | USART_CR3_WUFIE)
@@ -122,7 +122,7 @@ typedef struct _machine_uart_irq_map_t {
     uint16_t flag;
 } machine_uart_irq_map_t;
 
-STATIC const machine_uart_irq_map_t mp_uart_irq_map[] = {
+static const machine_uart_irq_map_t mp_uart_irq_map[] = {
     { USART_CR1_IDLEIE, UART_FLAG_IDLE}, // RX idle
     { USART_CR1_PEIE,   UART_FLAG_PE},   // parity error
     #if defined(STM32G0) || defined(STM32WL)
@@ -157,6 +157,18 @@ void uart_init0(void) {
     if (HAL_RCCEx_PeriphCLKConfig(&RCC_PeriphClkInit) != HAL_OK) {
         MICROPY_BOARD_FATAL_ERROR("HAL_RCCEx_PeriphCLKConfig");
     }
+    #elif defined(STM32N6)
+    // UART clock configuration, IC14 (max 100MHz).
+    LL_RCC_SetUSARTClockSource(LL_RCC_USART1_CLKSOURCE_IC14);
+    LL_RCC_SetUSARTClockSource(LL_RCC_USART2_CLKSOURCE_IC14);
+    LL_RCC_SetUSARTClockSource(LL_RCC_USART3_CLKSOURCE_IC14);
+    LL_RCC_SetUARTClockSource(LL_RCC_UART4_CLKSOURCE_IC14);
+    LL_RCC_SetUARTClockSource(LL_RCC_UART5_CLKSOURCE_IC14);
+    LL_RCC_SetUSARTClockSource(LL_RCC_USART6_CLKSOURCE_IC14);
+    LL_RCC_SetUARTClockSource(LL_RCC_UART7_CLKSOURCE_IC14);
+    LL_RCC_SetUARTClockSource(LL_RCC_UART8_CLKSOURCE_IC14);
+    LL_RCC_SetUARTClockSource(LL_RCC_UART9_CLKSOURCE_IC14);
+    LL_RCC_SetUSARTClockSource(LL_RCC_USART10_CLKSOURCE_IC14);
     #endif
 }
 
@@ -252,6 +264,9 @@ bool uart_init(machine_uart_obj_t *uart_obj,
 
     const machine_pin_obj_t *pins[4] = {0};
 
+    // Default pull is pull-up on RX and CTS (the input pins).
+    uint32_t pins_pull[4] = { GPIO_NOPULL, GPIO_PULLUP, GPIO_NOPULL, GPIO_PULLUP };
+
     switch (uart_obj->uart_id) {
         #if defined(MICROPY_HW_UART1_TX) && defined(MICROPY_HW_UART1_RX)
         case PYB_UART_1:
@@ -270,6 +285,12 @@ bool uart_init(machine_uart_obj_t *uart_obj,
                 pins[3] = MICROPY_HW_UART1_CTS;
             }
             #endif
+            #if defined(MICROPY_HW_UART1_RX_PULL)
+            pins_pull[1] = MICROPY_HW_UART1_RX_PULL;
+            #endif
+            #if defined(MICROPY_HW_UART1_CTS_PULL)
+            pins_pull[3] = MICROPY_HW_UART1_CTS_PULL;
+            #endif
             __HAL_RCC_USART1_CLK_ENABLE();
             break;
         #endif
@@ -295,6 +316,12 @@ bool uart_init(machine_uart_obj_t *uart_obj,
                 pins[3] = MICROPY_HW_UART2_CTS;
             }
             #endif
+            #if defined(MICROPY_HW_UART2_RX_PULL)
+            pins_pull[1] = MICROPY_HW_UART2_RX_PULL;
+            #endif
+            #if defined(MICROPY_HW_UART2_CTS_PULL)
+            pins_pull[3] = MICROPY_HW_UART2_CTS_PULL;
+            #endif
             __HAL_RCC_USART2_CLK_ENABLE();
             break;
         #endif
@@ -322,6 +349,12 @@ bool uart_init(machine_uart_obj_t *uart_obj,
                 pins[3] = MICROPY_HW_UART3_CTS;
             }
             #endif
+            #if defined(MICROPY_HW_UART3_RX_PULL)
+            pins_pull[1] = MICROPY_HW_UART3_RX_PULL;
+            #endif
+            #if defined(MICROPY_HW_UART3_CTS_PULL)
+            pins_pull[3] = MICROPY_HW_UART3_CTS_PULL;
+            #endif
             __HAL_RCC_USART3_CLK_ENABLE();
             break;
         #endif
@@ -358,6 +391,12 @@ bool uart_init(machine_uart_obj_t *uart_obj,
                 pins[3] = MICROPY_HW_UART4_CTS;
             }
             #endif
+            #if defined(MICROPY_HW_UART4_RX_PULL)
+            pins_pull[1] = MICROPY_HW_UART4_RX_PULL;
+            #endif
+            #if defined(MICROPY_HW_UART4_CTS_PULL)
+            pins_pull[3] = MICROPY_HW_UART4_CTS_PULL;
+            #endif
             break;
         #endif
 
@@ -393,6 +432,12 @@ bool uart_init(machine_uart_obj_t *uart_obj,
                 pins[3] = MICROPY_HW_UART5_CTS;
             }
             #endif
+            #if defined(MICROPY_HW_UART5_RX_PULL)
+            pins_pull[1] = MICROPY_HW_UART5_RX_PULL;
+            #endif
+            #if defined(MICROPY_HW_UART5_CTS_PULL)
+            pins_pull[3] = MICROPY_HW_UART5_CTS_PULL;
+            #endif
             break;
         #endif
 
@@ -419,6 +464,12 @@ bool uart_init(machine_uart_obj_t *uart_obj,
                 pins[3] = MICROPY_HW_UART6_CTS;
             }
             #endif
+            #if defined(MICROPY_HW_UART6_RX_PULL)
+            pins_pull[1] = MICROPY_HW_UART6_RX_PULL;
+            #endif
+            #if defined(MICROPY_HW_UART6_CTS_PULL)
+            pins_pull[3] = MICROPY_HW_UART6_CTS_PULL;
+            #endif
             __HAL_RCC_USART6_CLK_ENABLE();
             break;
         #endif
@@ -447,6 +498,12 @@ bool uart_init(machine_uart_obj_t *uart_obj,
                 pins[3] = MICROPY_HW_UART7_CTS;
             }
             #endif
+            #if defined(MICROPY_HW_UART7_RX_PULL)
+            pins_pull[1] = MICROPY_HW_UART7_RX_PULL;
+            #endif
+            #if defined(MICROPY_HW_UART7_CTS_PULL)
+            pins_pull[3] = MICROPY_HW_UART7_CTS_PULL;
+            #endif
             break;
         #endif
 
@@ -474,6 +531,12 @@ bool uart_init(machine_uart_obj_t *uart_obj,
                 pins[3] = MICROPY_HW_UART8_CTS;
             }
             #endif
+            #if defined(MICROPY_HW_UART8_RX_PULL)
+            pins_pull[1] = MICROPY_HW_UART8_RX_PULL;
+            #endif
+            #if defined(MICROPY_HW_UART8_CTS_PULL)
+            pins_pull[3] = MICROPY_HW_UART8_CTS_PULL;
+            #endif
             break;
         #endif
 
@@ -485,6 +548,9 @@ bool uart_init(machine_uart_obj_t *uart_obj,
             __HAL_RCC_UART9_CLK_ENABLE();
             pins[0] = MICROPY_HW_UART9_TX;
             pins[1] = MICROPY_HW_UART9_RX;
+            #if defined(MICROPY_HW_UART9_RX_PULL)
+            pins_pull[1] = MICROPY_HW_UART9_RX_PULL;
+            #endif
             break;
         #endif
 
@@ -502,6 +568,9 @@ bool uart_init(machine_uart_obj_t *uart_obj,
             #endif
             pins[0] = MICROPY_HW_UART10_TX;
             pins[1] = MICROPY_HW_UART10_RX;
+            #if defined(MICROPY_HW_UART10_RX_PULL)
+            pins_pull[1] = MICROPY_HW_UART10_RX_PULL;
+            #endif
             break;
         #endif
 
@@ -527,6 +596,12 @@ bool uart_init(machine_uart_obj_t *uart_obj,
                 pins[3] = MICROPY_HW_LPUART1_CTS;
             }
             #endif
+            #if defined(MICROPY_HW_LPUART1_RX_PULL)
+            pins_pull[1] = MICROPY_HW_LPUART1_RX_PULL;
+            #endif
+            #if defined(MICROPY_HW_LPUART1_CTS_PULL)
+            pins_pull[3] = MICROPY_HW_LPUART1_CTS_PULL;
+            #endif
             __HAL_RCC_LPUART1_CLK_ENABLE();
             break;
         #endif
@@ -551,6 +626,12 @@ bool uart_init(machine_uart_obj_t *uart_obj,
                 pins[3] = MICROPY_HW_LPUART2_CTS;
             }
             #endif
+            #if defined(MICROPY_HW_LPUART2_RX_PULL)
+            pins_pull[1] = MICROPY_HW_LPUART2_RX_PULL;
+            #endif
+            #if defined(MICROPY_HW_LPUART2_CTS_PULL)
+            pins_pull[3] = MICROPY_HW_LPUART2_CTS_PULL;
+            #endif
             __HAL_RCC_LPUART2_CLK_ENABLE();
             break;
         #endif
@@ -564,10 +645,7 @@ bool uart_init(machine_uart_obj_t *uart_obj,
 
     for (uint i = 0; i < 4; i++) {
         if (pins[i] != NULL) {
-            // Configure pull-up on RX and CTS (the input pins).
-            uint32_t pull = (i & 1) ? MP_HAL_PIN_PULL_UP : MP_HAL_PIN_PULL_NONE;
-            bool ret = mp_hal_pin_config_alt(pins[i], mode, pull, uart_fn, uart_unit);
-            if (!ret) {
+            if (!mp_hal_pin_config_alt(pins[i], mode, pins_pull[i], uart_fn, uart_unit)) {
                 return false;
             }
         }
@@ -587,7 +665,7 @@ bool uart_init(machine_uart_obj_t *uart_obj,
     huart.Init.HwFlowCtl = flow;
     huart.Init.OverSampling = UART_OVERSAMPLING_16;
 
-    #if defined(STM32G4)  // H7 and WB also have fifo..
+    #if defined(STM32G4) || defined(STM32H7) // WB also has a fifo..
     huart.FifoMode = UART_FIFOMODE_ENABLE;
     #endif
 
@@ -595,7 +673,7 @@ bool uart_init(machine_uart_obj_t *uart_obj,
     huart.Init.OneBitSampling = UART_ONE_BIT_SAMPLE_DISABLE;
     #endif
 
-    #if defined(STM32H7) || defined(STM32WB)
+    #if defined(STM32H7) || defined(STM32N6) || defined(STM32WB)
     // Compute the smallest prescaler that will allow the given baudrate.
     uint32_t presc = UART_PRESCALER_DIV1;
     if (uart_obj->uart_id == PYB_LPUART_1) {
@@ -623,6 +701,10 @@ bool uart_init(machine_uart_obj_t *uart_obj,
     uart_obj->is_enabled = true;
     uart_obj->attached_to_repl = false;
 
+    #if defined(STM32F4) || defined(STM32L1)
+    uart_obj->suppress_idle_irq = true;
+    #endif
+
     if (bits == UART_WORDLENGTH_9B && parity == UART_PARITY_NONE) {
         uart_obj->char_mask = 0x1ff;
         uart_obj->char_width = CHAR_WIDTH_9BIT;
@@ -635,6 +717,12 @@ bool uart_init(machine_uart_obj_t *uart_obj,
         uart_obj->char_width = CHAR_WIDTH_8BIT;
     }
 
+    #if defined(STM32H7)
+    HAL_UARTEx_SetTxFifoThreshold(&huart, UART_TXFIFO_THRESHOLD_1_8);
+    HAL_UARTEx_SetRxFifoThreshold(&huart, UART_RXFIFO_THRESHOLD_1_8);
+    HAL_UARTEx_EnableFifoMode(&huart);
+    #endif
+
     uart_obj->mp_irq_trigger = 0;
     uart_obj->mp_irq_obj = NULL;
 
@@ -900,6 +988,29 @@ uint32_t uart_get_source_freq(machine_uart_obj_t *self) {
         default:
             break;
     }
+
+    #elif defined(STM32N6)
+
+    static const uint16_t is_usart = 1 << 10 | 1 << 6 | 1 << 3 | 1 << 2 | 1 << 1;
+    static const uint32_t clksource[] = {
+        LL_RCC_USART1_CLKSOURCE,
+        LL_RCC_USART2_CLKSOURCE,
+        LL_RCC_USART3_CLKSOURCE,
+        LL_RCC_UART4_CLKSOURCE,
+        LL_RCC_UART5_CLKSOURCE,
+        LL_RCC_USART6_CLKSOURCE,
+        LL_RCC_UART7_CLKSOURCE,
+        LL_RCC_UART8_CLKSOURCE,
+        LL_RCC_UART9_CLKSOURCE,
+        LL_RCC_USART10_CLKSOURCE,
+    };
+
+    if (is_usart & (1 << self->uart_id)) {
+        uart_clk = LL_RCC_GetUSARTClockFreq(clksource[self->uart_id - 1]);
+    } else {
+        uart_clk = LL_RCC_GetUARTClockFreq(clksource[self->uart_id - 1]);
+    }
+
     #else
     if (self->uart_id == 1
         #if defined(USART6)
@@ -925,14 +1036,14 @@ uint32_t uart_get_baudrate(machine_uart_obj_t *self) {
     #if defined(LPUART1)
     if (self->uart_id == PYB_LPUART_1) {
         return LL_LPUART_GetBaudRate(self->uartx, uart_get_source_freq(self)
-            #if defined(STM32G0) || defined(STM32G4) || defined(STM32H5) || defined(STM32H7) || defined(STM32WB) || defined(STM32WL)
+            #if defined(STM32G0) || defined(STM32G4) || defined(STM32H5) || defined(STM32H7) || defined(STM32N6) || defined(STM32WB) || defined(STM32WL)
             , self->uartx->PRESC
             #endif
             );
     }
     #endif
     return LL_USART_GetBaudRate(self->uartx, uart_get_source_freq(self),
-        #if defined(STM32G0) || defined(STM32G4) || defined(STM32H5) || defined(STM32H7) || defined(STM32WB) || defined(STM32WL)
+        #if defined(STM32G0) || defined(STM32G4) || defined(STM32H5) || defined(STM32H7) || defined(STM32N6) || defined(STM32WB) || defined(STM32WL)
         self->uartx->PRESC,
         #endif
         LL_USART_OVERSAMPLING_16);
@@ -942,7 +1053,7 @@ void uart_set_baudrate(machine_uart_obj_t *self, uint32_t baudrate) {
     #if defined(LPUART1)
     if (self->uart_id == PYB_LPUART_1) {
         LL_LPUART_SetBaudRate(self->uartx, uart_get_source_freq(self),
-            #if defined(STM32G0) || defined(STM32G4) || defined(STM32H5) || defined(STM32H7) || defined(STM32WB) || defined(STM32WL)
+            #if defined(STM32G0) || defined(STM32G4) || defined(STM32H5) || defined(STM32H7) || defined(STM32N6) || defined(STM32WB) || defined(STM32WL)
             LL_LPUART_PRESCALER_DIV1,
             #endif
             baudrate);
@@ -950,7 +1061,7 @@ void uart_set_baudrate(machine_uart_obj_t *self, uint32_t baudrate) {
     }
     #endif
     LL_USART_SetBaudRate(self->uartx, uart_get_source_freq(self),
-        #if defined(STM32G0) || defined(STM32G4) || defined(STM32H5) || defined(STM32H7) || defined(STM32WB) || defined(STM32WL)
+        #if defined(STM32G0) || defined(STM32G4) || defined(STM32H5) || defined(STM32H7) || defined(STM32N6) || defined(STM32WB) || defined(STM32WL)
         LL_USART_PRESCALER_DIV1,
         #endif
         LL_USART_OVERSAMPLING_16, baudrate);
@@ -1001,7 +1112,7 @@ int uart_rx_char(machine_uart_obj_t *self) {
         return data;
     } else {
         // no buffering
-        #if defined(STM32F0) || defined(STM32F7) || defined(STM32G0) || defined(STM32G4) || defined(STM32H5) || defined(STM32L0) || defined(STM32L4) || defined(STM32H7) || defined(STM32WB) || defined(STM32WL)
+        #if defined(STM32F0) || defined(STM32F7) || defined(STM32G0) || defined(STM32G4) || defined(STM32H5) || defined(STM32L0) || defined(STM32L4) || defined(STM32H7) || defined(STM32N6) || defined(STM32WB) || defined(STM32WL)
         int data = self->uartx->RDR & self->char_mask;
         self->uartx->ICR = USART_ICR_ORECF; // clear ORE if it was set
         return data;
@@ -1038,7 +1149,7 @@ bool uart_tx_wait(machine_uart_obj_t *self, uint32_t timeout) {
 
 // Waits at most timeout milliseconds for UART flag to be set.
 // Returns true if flag is/was set, false on timeout.
-STATIC bool uart_wait_flag_set(machine_uart_obj_t *self, uint32_t flag, uint32_t timeout) {
+static bool uart_wait_flag_set(machine_uart_obj_t *self, uint32_t flag, uint32_t timeout) {
     // Note: we don't use WFI to idle in this loop because UART tx doesn't generate
     // an interrupt and the flag can be set quickly if the baudrate is large.
     uint32_t start = HAL_GetTick();
@@ -1069,26 +1180,23 @@ size_t uart_tx_data(machine_uart_obj_t *self, const void *src_in, size_t num_cha
     }
 
     uint32_t timeout;
-    if (self->uartx->CR3 & USART_CR3_CTSE) {
-        // CTS can hold off transmission for an arbitrarily long time. Apply
-        // the overall timeout rather than the character timeout.
-        timeout = self->timeout;
-    } else {
-        #if defined(STM32G4)
-        // With using UART FIFO, the timeout should be long enough that FIFO becomes empty.
-        // Since previous data transfer may be ongoing, the timeout must be multiplied
-        // timeout_char by FIFO size + 1.
-        // STM32G4 has 8 words FIFO.
-        timeout = (8 + 1) * self->timeout_char;
-        #else
-        // The timeout specified here is for waiting for the TX data register to
-        // become empty (ie between chars), as well as for the final char to be
-        // completely transferred.  The default value for timeout_char is long
-        // enough for 1 char, but we need to double it to wait for the last char
-        // to be transferred to the data register, and then to be transmitted.
-        timeout = 2 * self->timeout_char;
-        #endif
-    }
+    #if defined(STM32G4)
+    // With using UART FIFO, the timeout should be long enough that FIFO becomes empty.
+    // Since previous data transfer may be ongoing, the timeout must be multiplied
+    // timeout_char by FIFO size + 1.
+    // STM32G4 has 8 words FIFO.
+    timeout = (8 + 1) * self->timeout_char;
+    #elif defined(STM32H7)
+    // STM32H7 has 16 words FIFO.
+    timeout = (16 + 1) * self->timeout_char;
+    #else
+    // The timeout specified here is for waiting for the TX data register to
+    // become empty (ie between chars), as well as for the final char to be
+    // completely transferred.  The default value for timeout_char is long
+    // enough for 1 char, but we need to double it to wait for the last char
+    // to be transferred to the data register, and then to be transmitted.
+    timeout = 2 * self->timeout_char;
+    #endif
 
     const uint8_t *src = (const uint8_t *)src_in;
     size_t num_tx = 0;
@@ -1159,7 +1267,7 @@ void uart_irq_handler(mp_uint_t uart_id) {
             uint16_t next_head = (self->read_buf_head + 1) % self->read_buf_len;
             if (next_head != self->read_buf_tail) {
                 // only read data if room in buf
-                #if defined(STM32F0) || defined(STM32F7) || defined(STM32G0) || defined(STM32G4) || defined(STM32H5) || defined(STM32H7) || defined(STM32L0) || defined(STM32L4) || defined(STM32WB) || defined(STM32WL)
+                #if defined(STM32F0) || defined(STM32F7) || defined(STM32G0) || defined(STM32G4) || defined(STM32H5) || defined(STM32H7) || defined(STM32L0) || defined(STM32L4) || defined(STM32N6) || defined(STM32WB) || defined(STM32WL)
                 int data = self->uartx->RDR; // clears UART_FLAG_RXNE
                 #else
                 self->mp_irq_flags = self->uartx->SR; // resample to get any new flags since next read of DR will clear SR
@@ -1169,7 +1277,7 @@ void uart_irq_handler(mp_uint_t uart_id) {
                 data &= self->char_mask;
                 if (self->attached_to_repl && data == mp_interrupt_char) {
                     // Handle interrupt coming in on a UART REPL
-                    pendsv_kbd_intr();
+                    mp_sched_keyboard_interrupt();
                 } else {
                     if (self->char_width == CHAR_WIDTH_9BIT) {
                         ((uint16_t *)self->read_buf)[self->read_buf_head] = data;
@@ -1205,6 +1313,9 @@ void uart_irq_handler(mp_uint_t uart_id) {
             self->uartx->CR1 &= ~USART_CR1_RXNEIE;
         }
     }
+    if (self->suppress_idle_irq) {
+        self->mp_irq_flags &= ~USART_SR_IDLE;
+    }
     #else
     self->uartx->ICR = self->mp_irq_flags & (USART_ICR_IDLECF | USART_ICR_ORECF);
     #endif
@@ -1213,9 +1324,17 @@ void uart_irq_handler(mp_uint_t uart_id) {
     if (self->mp_irq_trigger & self->mp_irq_flags) {
         mp_irq_handler(self->mp_irq_obj);
     }
+
+    #if defined(STM32F4) || defined(STM32L1)
+    if (did_clear_sr) {
+        self->suppress_idle_irq = false;
+    } else {
+        self->suppress_idle_irq = true;
+    }
+    #endif
 }
 
-STATIC mp_uint_t uart_irq_trigger(mp_obj_t self_in, mp_uint_t new_trigger) {
+static mp_uint_t uart_irq_trigger(mp_obj_t self_in, mp_uint_t new_trigger) {
     machine_uart_obj_t *self = MP_OBJ_TO_PTR(self_in);
     uart_irq_config(self, false);
     self->mp_irq_trigger = new_trigger;
@@ -1223,7 +1342,7 @@ STATIC mp_uint_t uart_irq_trigger(mp_obj_t self_in, mp_uint_t new_trigger) {
     return 0;
 }
 
-STATIC mp_uint_t uart_irq_info(mp_obj_t self_in, mp_uint_t info_type) {
+static mp_uint_t uart_irq_info(mp_obj_t self_in, mp_uint_t info_type) {
     machine_uart_obj_t *self = MP_OBJ_TO_PTR(self_in);
     if (info_type == MP_IRQ_INFO_FLAGS) {
         return self->mp_irq_flags;
