@@ -30,6 +30,7 @@
 
 #include <stdio.h>
 #include <zephyr/kernel.h>
+#include <zephyr/version.h>
 #include <zephyr/debug/thread_analyzer.h>
 #include <zephyr/shell/shell.h>
 #include <zephyr/shell/shell_uart.h>
@@ -48,11 +49,16 @@ static mp_obj_t mod_current_tid(void) {
 static MP_DEFINE_CONST_FUN_OBJ_0(mod_current_tid_obj, mod_current_tid);
 
 #ifdef CONFIG_THREAD_ANALYZER
-static mp_obj_t mod_thread_analyze(void) {
+static mp_obj_t mod_thread_analyze(mp_obj_t cpu_in) {
+    #if KERNEL_VERSION_NUMBER >= ZEPHYR_VERSION(4, 0, 0)
+    unsigned int cpu = mp_obj_get_int(cpu_in);
+    thread_analyzer_print(cpu);
+    #else
     thread_analyzer_print();
+    #endif
     return mp_const_none;
 }
-static MP_DEFINE_CONST_FUN_OBJ_0(mod_thread_analyze_obj, mod_thread_analyze);
+static MP_DEFINE_CONST_FUN_OBJ_1(mod_thread_analyze_obj, mod_thread_analyze);
 #endif
 
 #ifdef CONFIG_SHELL_BACKEND_SERIAL
