@@ -53,7 +53,7 @@ void mp_asm_base_start_pass(mp_asm_base_t *as, int pass) {
     } else {
         // allocating executable RAM is platform specific
         MP_PLAT_ALLOC_EXEC(as->code_offset, (void **)&as->code_base, &as->code_size);
-        assert(as->code_base != NULL);
+        assert(as->code_size == 0 || as->code_base != NULL);
     }
     as->pass = pass;
     as->suppress = false;
