@@ -84,7 +84,7 @@ static void dict_print(const mp_print_t *print, mp_obj_t self_in, mp_print_kind_
         #endif
     }
     if (MICROPY_PY_COLLECTIONS_ORDEREDDICT && self->base.type != &mp_type_dict && kind != PRINT_JSON) {
-        mp_printf(print, "%q(", self->base.type->name);
+        mp_printf(print, "%q(", (qstr)self->base.type->name);
     }
     mp_print_str(print, "{");
     size_t cur = 0;
