@@ -1,9 +1,6 @@
 # test await expression
 
-try:
-    import usys as sys
-except ImportError:
-    import sys
+import sys
 if sys.implementation.name == 'micropython':
     # uPy allows normal generators to be awaitables
     coroutine = lambda f: f
