@@ -1,10 +1,7 @@
 # test attrtuple
 # we can't test this type directly so we use sys.implementation object
 
-try:
-    import usys as sys
-except ImportError:
-    import sys
+import sys
 t = sys.implementation
 
 # It can be just a normal tuple on small ports
