@@ -32,11 +32,27 @@ print(range(1, 4)[:])
 print(range(1, 4)[0:])
 print(range(1, 4)[1:])
 print(range(1, 4)[:-1])
+print(range(4, 1)[:])
+print(range(4, 1)[0:])
+print(range(4, 1)[1:])
+print(range(4, 1)[:-1])
 print(range(7, -2, -4)[:])
 print(range(1, 100, 5)[5:15:3])
 print(range(1, 100, 5)[15:5:-3])
 print(range(100, 1, -5)[5:15:3])
 print(range(100, 1, -5)[15:5:-3])
+print(range(1, 100, 5)[5:15:-3])
+print(range(1, 100, 5)[15:5:3])
+print(range(100, 1, -5)[5:15:-3])
+print(range(100, 1, -5)[15:5:3])
+print(range(1, 100, 5)[5:15:3])
+print(range(1, 100, 5)[15:5:-3])
+print(range(1, 100, -5)[5:15:3])
+print(range(1, 100, -5)[15:5:-3])
+print(range(1, 100, 5)[5:15:-3])
+print(range(1, 100, 5)[15:5:3])
+print(range(1, 100, -5)[5:15:-3])
+print(range(1, 100, -5)[15:5:3])
 
 # for this case uPy gives a different stop value but the listed elements are still correct
 print(list(range(7, -2, -4)[2:-2:]))
