@@ -1,5 +1,5 @@
 """
-categories: Core
+categories: Core,f-strings
 description: f-strings don't support concatenation with adjacent literals if the adjacent literals contain braces
 cause: MicroPython is optimised for code space.
 workaround: Use the + operator between literal strings when they are not both f-strings
