@@ -1,5 +1,5 @@
 try:
-    import binascii
+    from binascii import unhexlify
 except ImportError:
     print("SKIP")
     raise SystemExit
@@ -10,14 +10,14 @@ for x in (
     b"7f80ff",
     b"313233344142434461626364",
 ):
-    print(binascii.unhexlify(x))
+    print(unhexlify(x))
 
 try:
-    a = binascii.unhexlify(b"0")  # odd buffer length
+    a = unhexlify(b"0")  # odd buffer length
 except ValueError:
     print("ValueError")
 
 try:
-    a = binascii.unhexlify(b"gg")  # digit not hex
+    a = unhexlify(b"gg")  # digit not hex
 except ValueError:
     print("ValueError")
