@@ -1,6 +1,6 @@
 # Test blit between different color spaces
 try:
-    import framebuf, usys
+    import framebuf, sys
 except ImportError:
     print("SKIP")
     raise SystemExit
@@ -30,6 +30,6 @@ fbd.blit(fbc, 0, 0, -1, palette)
 
 print(fbd.pixel(0, 0) == fg)
 print(fbd.pixel(7, 7) == fg)
-print(fbd.pixel(8, 8) == 0)  # Ouside blit
+print(fbd.pixel(8, 8) == 0)  # Outside blit
 print(fbd.pixel(0, 1) == bg)
 print(fbd.pixel(1, 0) == bg)
