@@ -12,5 +12,8 @@ for i in range(8):
     print(uctypes.addressof(uctypes.bytearray_at(1 << i, 8)))
 
 # Test address that is bigger than the greatest small-int but still within the address range.
-large_addr = maxsize + 1
-print(uctypes.addressof(uctypes.bytearray_at(large_addr, 8)) == large_addr)
+try:
+    large_addr = maxsize + 1
+    print(uctypes.addressof(uctypes.bytearray_at(large_addr, 8)) == large_addr)
+except OverflowError:
+    print(True)  # systems with 64-bit bigints will overflow on the above operation
