@@ -1,11 +1,11 @@
 # Test for VfsLfs using a RAM device, mtime feature
 
 try:
-    import time, os
+    import time, vfs
 
-    time.time
+    time.time_ns
     time.sleep
-    os.VfsLfs2
+    vfs.VfsLfs2
 except (ImportError, AttributeError):
     print("SKIP")
     raise SystemExit
@@ -44,24 +44,25 @@ def test(bdev, vfs_class):
 
     # construction
     print("mtime=True")
-    vfs = vfs_class(bdev, mtime=True)
+    fs = vfs_class(bdev, mtime=True)
 
     # Create an empty file, should have a timestamp.
-    current_time = int(time.time())
-    vfs.open("test1", "wt").close()
+    # Use time_ns() for current time because that's what's used for VfsLfs2 time.
+    current_time = time.time_ns() // 1_000_000_000
+    fs.open("test1", "wt").close()
 
     # Wait 1 second so mtime will increase by at least 1.
     time.sleep(1)
 
     # Create another empty file, should have a timestamp.
-    vfs.open("test2", "wt").close()
+    fs.open("test2", "wt").close()
 
     # Stat the files and check mtime is non-zero.
-    stat1 = vfs.stat("test1")
-    stat2 = vfs.stat("test2")
+    stat1 = fs.stat("test1")
+    stat2 = fs.stat("test2")
     print(stat1[8] != 0, stat2[8] != 0)
 
-    # Check that test1 has mtime which matches time.time() at point of creation.
+    # Check that test1 has mtime which matches time.time_ns() at point of creation.
     print(current_time <= stat1[8] <= current_time + 1)
 
     # Check that test1 is older than test2.
@@ -71,34 +72,34 @@ def test(bdev, vfs_class):
     time.sleep(1)
 
     # Open test1 for reading and ensure mtime did not change.
-    vfs.open("test1", "rt").close()
-    print(vfs.stat("test1") == stat1)
+    fs.open("test1", "rt").close()
+    print(fs.stat("test1") == stat1)
 
     # Open test1 for writing and ensure mtime increased from the previous value.
-    vfs.open("test1", "wt").close()
+    fs.open("test1", "wt").close()
     stat1_old = stat1
-    stat1 = vfs.stat("test1")
+    stat1 = fs.stat("test1")
     print(stat1_old[8] < stat1[8])
 
     # Unmount.
-    vfs.umount()
+    fs.umount()
 
     # Check that remounting with mtime=False can read the timestamps.
     print("mtime=False")
-    vfs = vfs_class(bdev, mtime=False)
-    print(vfs.stat("test1") == stat1)
-    print(vfs.stat("test2") == stat2)
-    f = vfs.open("test1", "wt")
+    fs = vfs_class(bdev, mtime=False)
+    print(fs.stat("test1") == stat1)
+    print(fs.stat("test2") == stat2)
+    f = fs.open("test1", "wt")
     f.close()
-    print(vfs.stat("test1") == stat1)
-    vfs.umount()
+    print(fs.stat("test1") == stat1)
+    fs.umount()
 
     # Check that remounting with mtime=True still has the timestamps.
     print("mtime=True")
-    vfs = vfs_class(bdev, mtime=True)
-    print(vfs.stat("test1") == stat1)
-    print(vfs.stat("test2") == stat2)
-    vfs.umount()
+    fs = vfs_class(bdev, mtime=True)
+    print(fs.stat("test1") == stat1)
+    print(fs.stat("test2") == stat2)
+    fs.umount()
 
 
 try:
@@ -107,4 +108,4 @@ except MemoryError:
     print("SKIP")
     raise SystemExit
 
-test(bdev, os.VfsLfs2)
+test(bdev, vfs.VfsLfs2)
