@@ -3,5 +3,6 @@ import micropython
 
 if not hasattr(micropython, "stack_use"):
     print("SKIP")
-else:
-    print(type(micropython.stack_use()))  # output varies
+    raise SystemExit
+
+print(type(micropython.stack_use()))  # output varies
