@@ -17,10 +17,12 @@ def test(addr):
         # mbedtls produces "mbedtls -0x7200: SSL - An invalid SSL record was received"
         # axtls produces "RECORD_OVERFLOW" but also prints "TLS buffer overflow,..."
         # CPython produces "[SSL: WRONG_VERSION_NUMBER] wrong version number (_ssl.c:1108)"
+        # CPython newer version produces "[SSL] record layer failure (_ssl.c:1000)"
         ok = (
             "SSL_INVALID_RECORD" in str(e)
             or "RECORD_OVERFLOW" in str(e)
             or "wrong version" in str(e)
+            or "record layer failure" in str(e)
         )
         print("wrap:", ok)
         if not ok:
