@@ -2,6 +2,7 @@
 #
 # MIT license; Copyright (c) 2016 Damien P. George on behalf of Pycom Ltd
 
+import time
 import _thread
 
 
@@ -40,7 +41,7 @@ for i in range(n_thread):
 
 # busy wait for threads to finish
 while n_finished < n_thread:
-    pass
+    time.sleep(0)
 
 # check user instance has correct contents
 print(user.a, user.b, user.c)
