@@ -2,11 +2,13 @@
 #
 # MIT license; Copyright (c) 2016 Damien P. George on behalf of Pycom Ltd
 
+import time
 import _thread
 
 # the shared set
 se = set([-1, -2, -3, -4])
 
+
 # main thread function
 def th(n, lo, hi):
     for repeat in range(n):
@@ -32,7 +34,7 @@ for i in range(n_thread):
 
 # busy wait for threads to finish
 while n_finished < n_thread:
-    pass
+    time.sleep(0)
 
 # check set has correct contents
 print(sorted(se))
