@@ -2,6 +2,7 @@
 #
 # MIT license; Copyright (c) 2016 Damien P. George on behalf of Pycom Ltd
 
+import time
 import _thread
 
 
@@ -24,5 +25,5 @@ _thread.start_new_thread(thread_entry, ())
 
 # busy wait for thread to finish
 while not finished:
-    pass
+    time.sleep(0)
 print("done")
