@@ -1,5 +1,5 @@
 # test raising exception within thread which is not caught
-import utime
+import time
 import _thread
 
 
@@ -8,5 +8,5 @@ def thread_entry():
 
 
 _thread.start_new_thread(thread_entry, ())
-utime.sleep(1)
+time.sleep(1)
 print("done")
