@@ -2,10 +2,7 @@
 #
 # MIT license; Copyright (c) 2016 Damien P. George on behalf of Pycom Ltd
 
-try:
-    import utime as time
-except ImportError:
-    import time
+import time
 import _thread
 
 lock = _thread.allocate_lock()
