@@ -1,10 +1,9 @@
 # test setting the thread stack size
 #
 # MIT license; Copyright (c) 2016 Damien P. George on behalf of Pycom Ltd
-try:
-    import usys as sys
-except ImportError:
-    import sys
+
+import sys
+import time
 import _thread
 
 # different implementations have different minimum sizes
@@ -53,5 +52,5 @@ _thread.stack_size()
 
 # busy wait for threads to finish
 while n_finished < n_thread:
-    pass
+    time.sleep(0)
 print("done")
