@@ -5,7 +5,7 @@ for i in range(len(s)):
 
 # Test all three forms of Unicode escape, and
 # all blocks of UTF-8 byte patterns
-s = "a\xA9\xFF\u0123\u0800\uFFEE\U0001F44C"
+s = "a\xa9\xff\u0123\u0800\uffee\U0001f44c"
 for i in range(-len(s), len(s)):
     print("s[%d]: %s   %X" % (i, s[i], ord(s[i])))
     print("s[:%d]: %d chars, '%s'" % (i, len(s[:i]), s[:i]))
