@@ -65,9 +65,8 @@ def main(repo_path, output_path):
                 )
                 sys.exit(1)
 
-            # Use "id" if specified, otherwise default to board dir (e.g. "PYBV11").
-            # We allow boards to override ID for the historical build names.
-            blob["id"] = blob.get("id", os.path.basename(board_dir))
+            # The ID of a board is the board directory (e.g. "PYBV11").
+            blob["id"] = os.path.basename(board_dir)
 
             # Check for duplicate board IDs.
             if blob["id"] in board_ids:
@@ -92,7 +91,18 @@ def main(repo_path, output_path):
                 f.write("\n\n## Installation instructions\n")
             for deploy in blob["deploy"]:
                 with open(os.path.join(board_dir, deploy), "r") as fin:
-                    f.write(fin.read())
+                    body = fin.read()
+                    # any key in the board.json file can be substituted via Python str.format()
+                    try:
+                        body = body.format(**blob)
+                    except Exception as e:
+                        raise RuntimeError(
+                            "Failed to format deploy file {} according to {}: {}".format(
+                                fin.name, board_json, e
+                            )
+                        )
+                    f.write(body)
+                    f.write("\n")
 
     # Write the full index for the website to load.
     with open(os.path.join(output_path, "index.json"), "w") as f:
