@@ -7,12 +7,15 @@ import urllib.request
 import json
 import tempfile
 import os
+import os.path
 
 from .commands import CommandError, show_progress_bar
 
 
 _PACKAGE_INDEX = "https://micropython.org/pi/v2"
 
+allowed_mip_url_prefixes = ("http://", "https://", "github:", "gitlab:")
+
 
 # This implements os.makedirs(os.dirname(path))
 def _ensure_path_exists(transport, path):
@@ -31,6 +34,15 @@ def _ensure_path_exists(transport, path):
         prefix += "/"
 
 
+# Check if the specified path exists and matches the hash.
+def _check_exists(transport, path, short_hash):
+    try:
+        remote_hash = transport.fs_hashfile(path, "sha256")
+    except FileNotFoundError:
+        return False
+    return remote_hash.hex()[: len(short_hash)] == short_hash
+
+
 def _rewrite_url(url, branch=None):
     if not branch:
         branch = "HEAD"
@@ -62,50 +74,72 @@ def _rewrite_url(url, branch=None):
 
 
 def _download_file(transport, url, dest):
-    try:
-        with urllib.request.urlopen(url) as src:
-            data = src.read()
-            print("Installing:", dest)
-            _ensure_path_exists(transport, dest)
-            transport.fs_writefile(dest, data, progress_callback=show_progress_bar)
-    except urllib.error.HTTPError as e:
-        if e.status == 404:
-            raise CommandError(f"File not found: {url}")
-        else:
-            raise CommandError(f"Error {e.status} requesting {url}")
-    except urllib.error.URLError as e:
-        raise CommandError(f"{e.reason} requesting {url}")
+    if url.startswith(allowed_mip_url_prefixes):
+        try:
+            with urllib.request.urlopen(url) as src:
+                data = src.read()
+        except urllib.error.HTTPError as e:
+            if e.status == 404:
+                raise CommandError(f"File not found: {url}")
+            else:
+                raise CommandError(f"Error {e.status} requesting {url}")
+        except urllib.error.URLError as e:
+            raise CommandError(f"{e.reason} requesting {url}")
+    else:
+        if "\\" in url:
+            raise CommandError(f'Use "/" instead of "\\" in file URLs: {url!r}\n')
+        try:
+            with open(url, "rb") as f:
+                data = f.read()
+        except OSError as e:
+            raise CommandError(f"{e.strerror} opening {url}")
+
+    print("Installing:", dest)
+    _ensure_path_exists(transport, dest)
+    transport.fs_writefile(dest, data, progress_callback=show_progress_bar)
 
 
 def _install_json(transport, package_json_url, index, target, version, mpy):
-    try:
-        with urllib.request.urlopen(_rewrite_url(package_json_url, version)) as response:
-            package_json = json.load(response)
-    except urllib.error.HTTPError as e:
-        if e.status == 404:
-            raise CommandError(f"Package not found: {package_json_url}")
-        else:
-            raise CommandError(f"Error {e.status} requesting {package_json_url}")
-    except urllib.error.URLError as e:
-        raise CommandError(f"{e.reason} requesting {package_json_url}")
+    base_url = ""
+    if package_json_url.startswith(allowed_mip_url_prefixes):
+        try:
+            with urllib.request.urlopen(_rewrite_url(package_json_url, version)) as response:
+                package_json = json.load(response)
+        except urllib.error.HTTPError as e:
+            if e.status == 404:
+                raise CommandError(f"Package not found: {package_json_url}")
+            else:
+                raise CommandError(f"Error {e.status} requesting {package_json_url}")
+        except urllib.error.URLError as e:
+            raise CommandError(f"{e.reason} requesting {package_json_url}")
+        base_url = package_json_url.rpartition("/")[0]
+    elif package_json_url.endswith(".json"):
+        try:
+            with open(package_json_url, "r") as f:
+                package_json = json.load(f)
+        except OSError:
+            raise CommandError(f"Error opening {package_json_url}")
+        base_url = os.path.dirname(package_json_url)
+    else:
+        raise CommandError(f"Invalid url for package: {package_json_url}")
     for target_path, short_hash in package_json.get("hashes", ()):
         fs_target_path = target + "/" + target_path
-        file_url = f"{index}/file/{short_hash[:2]}/{short_hash}"
-        _download_file(transport, file_url, fs_target_path)
+        if _check_exists(transport, fs_target_path, short_hash):
+            print("Exists:", fs_target_path)
+        else:
+            file_url = f"{index}/file/{short_hash[:2]}/{short_hash}"
+            _download_file(transport, file_url, fs_target_path)
     for target_path, url in package_json.get("urls", ()):
         fs_target_path = target + "/" + target_path
+        if base_url and not url.startswith(allowed_mip_url_prefixes):
+            url = f"{base_url}/{url}"  # Relative URLs
         _download_file(transport, _rewrite_url(url, version), fs_target_path)
     for dep, dep_version in package_json.get("deps", ()):
         _install_package(transport, dep, index, target, dep_version, mpy)
 
 
 def _install_package(transport, package, index, target, version, mpy):
-    if (
-        package.startswith("http://")
-        or package.startswith("https://")
-        or package.startswith("github:")
-        or package.startswith("gitlab:")
-    ):
+    if package.startswith(allowed_mip_url_prefixes):
         if package.endswith(".py") or package.endswith(".mpy"):
             print(f"Downloading {package} to {target}")
             _download_file(
@@ -118,6 +152,8 @@ def _install_package(transport, package, index, target, version, mpy):
                     package += "/"
                 package += "package.json"
             print(f"Installing {package} to {target}")
+    elif package.endswith(".json"):
+        pass
     else:
         if not version:
             version = "latest"
@@ -151,7 +187,11 @@ def do_mip(state, args):
 
             if args.target is None:
                 state.transport.exec("import sys")
-                lib_paths = [p for p in state.transport.eval("sys.path") if p.endswith("/lib")]
+                lib_paths = [
+                    p
+                    for p in state.transport.eval("sys.path")
+                    if not p.startswith("/rom") and p.endswith("/lib")
+                ]
                 if lib_paths and lib_paths[0]:
                     args.target = lib_paths[0]
                 else:
