@@ -36,21 +36,48 @@
 # as a command line tool and a library for interacting with devices.
 
 import ast, io, os, re, struct, sys, time
+import serial
+import serial.tools.list_ports
 from errno import EPERM
 from .console import VT_ENABLED
 from .transport import TransportError, TransportExecError, Transport
 
+VID_ESPRESSIF = 0x303A  # Espressif Incorporated
+PID_ESPRESSIF_SERIAL_JTAG = 0x1001  # Serial/JTAG peripheral of ESP32-S3,C3,C6
+
+
+def has_espressif_dtr_quirk(devicename):
+    """ESP8266 and ESP32 dev boards use the DTR and RTS lines to trigger reset &
+    reset into bootloader mode. This can causes spurious reset issues on Windows.
+
+    Apply the quirk to any USB/Serial chip on Windows that isn't using the
+    Microsoft CDC-ACM driver, or to the integrated Espressif Serial/JTAG device.
+
+    Don't apply it to Espressif boards running TinyUSB, as TinyUSB uses DTR
+    to determine if the CDC port is open (and there's no spurious reset issue).
+    """
+    portinfo = list(serial.tools.list_ports.grep(devicename))  # type: ignore
+    if not portinfo:
+        return False
+
+    def port_attr(name):
+        return getattr(portinfo[0], name, None)
+
+    return (port_attr("vid"), port_attr("pid")) == (
+        VID_ESPRESSIF,
+        PID_ESPRESSIF_SERIAL_JTAG,
+    ) or port_attr("manufacturer") != "Microsoft"
+
 
 class SerialTransport(Transport):
+    fs_hook_mount = "/remote"  # MUST match the mount point in fs_hook_code
+
     def __init__(self, device, baudrate=115200, wait=0, exclusive=True, timeout=None):
         self.in_raw_repl = False
         self.use_raw_paste = True
         self.device_name = device
         self.mounted = False
 
-        import serial
-        import serial.tools.list_ports
-
         # Set options, and exclusive if pyserial supports it
         serial_kwargs = {
             "baudrate": baudrate,
@@ -68,9 +95,7 @@ class SerialTransport(Transport):
                 elif os.name == "nt":
                     self.serial = serial.Serial(**serial_kwargs)
                     self.serial.port = device
-                    portinfo = list(serial.tools.list_ports.grep(device))  # type: ignore
-                    if portinfo and portinfo[0].manufacturer != "Microsoft":
-                        # ESP8266/ESP32 boards use RTS/CTS for flashing and boot mode selection.
+                    if has_espressif_dtr_quirk(device):
                         # DTR False: to avoid using the reset button will hang the MCU in bootloader mode
                         # RTS False: to prevent pulses on rts on serial.close() that would POWERON_RESET an ESPxx
                         self.serial.dtr = False  # DTR False = gpio0 High = Normal boot
@@ -375,7 +400,11 @@ class SerialTransport(Transport):
         self.serial = self.serial.orig_serial
 
         # Provide a message about the remount.
-        out_callback(bytes(f"\r\nRemount local directory {self.cmd.root} at /remote\r\n", "utf8"))
+        out_callback(
+            bytes(
+                f"\r\nRemount local directory {self.cmd.root} at {self.fs_hook_mount}\r\n", "utf8"
+            )
+        )
 
         # Enter raw REPL and re-mount the remote filesystem.
         self.serial.write(b"\x01")
@@ -392,7 +421,7 @@ class SerialTransport(Transport):
 
     def umount_local(self):
         if self.mounted:
-            self.exec('os.umount("/remote")')
+            self.exec(f'os.umount("{self.fs_hook_mount}")')
             self.mounted = False
             self.serial = self.serial.orig_serial
 
@@ -413,7 +442,7 @@ fs_hook_cmds = {
     "CMD_RMDIR": 13,
 }
 
-fs_hook_code = """\
+fs_hook_code = f"""\
 import os, io, struct, micropython
 
 SEEK_SET = 0
@@ -746,8 +775,8 @@ class RemoteFS:
 
 
 def __mount():
-    os.mount(RemoteFS(RemoteCommand()), '/remote')
-    os.chdir('/remote')
+    os.mount(RemoteFS(RemoteCommand()), '{SerialTransport.fs_hook_mount}')
+    os.chdir('{SerialTransport.fs_hook_mount}')
 """
 
 # Apply basic compression on hook code.
