@@ -6,14 +6,11 @@ import os.path
 argparser = argparse.ArgumentParser(description="Compile all .py files to .mpy recursively")
 argparser.add_argument("-o", "--out", help="output directory (default: input dir)")
 argparser.add_argument("--target", help="select MicroPython target config")
-argparser.add_argument(
-    "-mcache-lookup-bc", action="store_true", help="cache map lookups in the bytecode"
-)
 argparser.add_argument("dir", help="input directory")
 args = argparser.parse_args()
 
 TARGET_OPTS = {
-    "unix": "-mcache-lookup-bc",
+    "unix": "",
     "baremetal": "",
 }
 
